@@ -5,48 +5,48 @@
  */
 
 #pragma once
-#include "kldap_export.h"
+#include "kldapwidgets_export.h"
 #include <KConfigGroup>
-#include <KLDAP/LdapServer>
+#include <KLDAPCore/LdapServer>
 #include <QObject>
 namespace QKeychain
 {
 class Job;
 }
-namespace KLDAP
+namespace KLDAPWidgets
 {
-class KLDAP_EXPORT LdapClientSearchConfigWriteConfigJob : public QObject
+class KLDAPWIDGETS_EXPORT LdapClientSearchConfigWriteConfigJob : public QObject
 {
     Q_OBJECT
 public:
     explicit LdapClientSearchConfigWriteConfigJob(QObject *parent = nullptr);
     ~LdapClientSearchConfigWriteConfigJob() override;
 
-    Q_REQUIRED_RESULT bool canStart() const;
+    [[nodiscard]] bool canStart() const;
     void start();
 
-    Q_REQUIRED_RESULT bool active() const;
+    [[nodiscard]] bool active() const;
     void setActive(bool newActive);
 
-    Q_REQUIRED_RESULT int serverIndex() const;
+    [[nodiscard]] int serverIndex() const;
     void setServerIndex(int newServerIndex);
 
-    Q_REQUIRED_RESULT KConfigGroup config() const;
+    [[nodiscard]] KConfigGroup config() const;
     void setConfig(const KConfigGroup &newConfig);
 
-    Q_REQUIRED_RESULT KLDAP::LdapServer server() const;
-    void setServer(const KLDAP::LdapServer &server);
+    [[nodiscard]] KLDAPCore::LdapServer server() const;
+    void setServer(const KLDAPCore::LdapServer &server);
 
 Q_SIGNALS:
     void configSaved();
 
 private:
-    void writeLdapClientConfigFinished();
-    void writeConfig();
+    KLDAPWIDGETS_NO_EXPORT void writeLdapClientConfigFinished();
+    KLDAPWIDGETS_NO_EXPORT void writeConfig();
     int mServerIndex = -1;
     KConfigGroup mConfig;
     bool mActive = false;
-    KLDAP::LdapServer mServer;
+    KLDAPCore::LdapServer mServer;
 };
 
 }
